@@ -1,11 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__all__ = ['MoQuerySet', 'MoManager']
-
+from __future__ import unicode_literals
 import copy
 import inspect
-import logging
 from django.db import transaction
 from django.db.models import Model, Manager, get_model
 from django.db.models.query import RawQuerySet
@@ -13,12 +11,8 @@ from django.utils import six
 from mosql.query import select, join, delete
 from mosql.util import raw, identifier, paren
 from .db.handlers import get_engine_handler
-try:
-    basestring
-except NameError:   # If basestring is not a thing, just alias it to str
-    basestring = str
 
-logger = logging.getLogger(__name__)
+__all__ = ['MoQuerySet', 'MoManager']
 
 
 class MoQuerySet(object):
@@ -272,7 +266,7 @@ class MoQuerySet(object):
             ``JOIN`` types. If ommited, a suitable type will be inferred
             automatically.
         """
-        if isinstance(model, basestring):   # Try to lazy-load the model
+        if isinstance(model, six.string_types):   # Try to lazy-load the model
             parts = model.split('.')
             if len(parts) == 2 and all(parts):
                 model = get_model(*parts) or model
@@ -281,7 +275,7 @@ class MoQuerySet(object):
 
         if inspect.isclass(model) and issubclass(model, Model):
             table = model._meta.db_table
-        elif isinstance(model, basestring):
+        elif isinstance(model, six.string_types):
             table = model
         else:
             raise TypeError('join() arg 1 must be a Django model or a str '
